Module metrics — Operalib 0.1.0 documentation

# Module metrics

`operalib.metrics` define upplementary metrics not available in scikit-learn

`operalib.metrics.` `first_periodic_kernel`(X, Y=None, gamma=None, period=None)

  Compute the first periodic kernel between X and Y.

  Parameters: | X : array of shape (n_samples_X, n_features) Y : array of shape (n_samples_Y, n_features) gamma : float, default None If None, default to 1.0 / n_samples_X period : float, default None If None, default to 2 * pi. This parameter should not be default as wrong estimation lead to poor learning score.
  Returns: | kernel_matrix : array of shape (n_samples_X, n_samples_Y)